package com.qbizm.kramerius.webclient.repository;

import java.math.BigInteger;
import java.util.List;

import com.qbizm.kramerius.webclient.repository.dto.Condition;
import com.qbizm.kramerius.webclient.repository.dto.DatastreamDef;
import com.qbizm.kramerius.webclient.repository.dto.FieldSearchResult;
import com.qbizm.kramerius.webclient.repository.dto.MIMETypedStream;
import com.qbizm.kramerius.webclient.repository.dto.ObjectFields;
import com.qbizm.kramerius.webclient.repository.dto.ObjectProfile;
import com.qbizm.kramerius.webclient.repository.dto.RepositoryInfo;

/**
 * Interface for FEDORA repository 
 * <p>
 * Copyright (c) 2008 Qbizm technologies, a.s. All rights reserved.
 * <p>
 * This software is the proprietary information of Qbizm technologies, a.s. Use is subject to
 * license terms.
 * <p>
 * Requirements: <br>
 * Keywords: <br>
 * 
 * @author <a href="mailto:pavel.slavicek@qbizm.cz">Pavel Slavicek</a>
 * @version $$ $$
 */
public interface Repository {
	
  /**
   * Reads basic repository information
   * @return
   * @throws RepositoryException
   */
	RepositoryInfo getRepositoryInfo() throws RepositoryException;
	
	/**
	 * Returns object's profile
	 * @param pid
	 * @param asOfDateTime
	 * @return
	 * @throws RepositoryException
	 * @TODO Check it - WS returns bad data
	 */
	ObjectProfile getObjectProfile(String pid, java.lang.String asOfDateTime)  throws RepositoryException;

	/**
	 * Returns information about object's data streams
	 */
	List<DatastreamDef> getDataStreamsInfo(String pid, String asOfDateTime) throws RepositoryException;
	
	/**
	 * Returns object's data stream
	 * @param pid
	 * @param dsID
	 * @param asOfDateTime
	 * @return
	 * @throws RepositoryException
	 */
	MIMETypedStream getDatastream(String pid, String dsID, String asOfDateTime) throws RepositoryException;
	
	/**
	 * Returns specified object's fields
	 * @param fields comma separated list of requested fields
	 * @param pid of requested object
	 * @return ObjectFields object or null
	 * @throws RepositoryException
	 */
	ObjectFields getObjectFileds(String fields, String pid) throws RepositoryException;
	
	/**
	 * Basic search operation for Fedora
	 * @param resultFields
	 * @param maxResults
	 * @param searchTerms
	 * @param conditions
	 * @return
	 * @throws RepositoryException
	 */
	FieldSearchResult findObjects(List<String> resultFields, BigInteger maxResults, String searchTerms, List<Condition> conditions) throws RepositoryException;
	
	/**
	 * Search operation for Resource Index search - relationships
	 * @param query
	 * @param targetObject
	 * @return
	 * @throws RepositoryException
	 */
	List<Object> riSearch(String query, Class<?> targetObject) throws RepositoryException; 
}
