package com.qbizm.kramerius.webclient.repository;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.util.LinkedList;
import java.util.List;

import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.apache.log4j.Logger;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.ext.DefaultHandler2;

/**
 * Parser for response XML from Fedora Resource Index Search in SPARQL format 
 * <p>
 * Copyright (c) 2008 Qbizm technologies, a.s. All rights reserved.
 * <p>
 * This software is the proprietary information of Qbizm technologies, a.s. Use is subject to
 * license terms.
 * <p>
 * Requirements: <br>
 * Keywords: <br>
 * 
 * @author <a href="mailto:pavel.slavicek@qbizm.cz">Pavel Slavicek</a>
 * @version $$ $$
 */
public class SparqlParser extends DefaultHandler2 {

  /** Logger **/
  private static final Logger LOG = Logger.getLogger(SparqlParser.class);

  /** Name of XML elements **/
  private static final String XML_ELEMENT_RESULT = "result";

  private static final String XML_ELEMENT_RESULTS = "results";

  private static final String XML_ELEMENT_DATATYPE = "datatype";

  private String actElem = null;

  private Object actObject;

  private int results = 0;

  private int result = 0;

  private List<Object> resultArray = new LinkedList<Object>();

  private Class<?> resultClass;

  private StringBuffer chars = new StringBuffer();

  /**
   * Constructor
   * 
   * @param obj
   * @param c
   */
  public SparqlParser(Class<?> obj, byte[] c) {
    super();
    resultClass = obj;
    SAXParserFactory spf = SAXParserFactory.newInstance();
    try {
      spf.setValidating(false);
      SAXParser parser = spf.newSAXParser();
      InputStream is = new ByteArrayInputStream(c);
      parser.parse(is, this);
    } catch (Exception e) {
      LOG.error(e.getMessage(), e);
    }
  }

  /**
   * Characters SAX event
   * 
   * @param c characters
   * @param i start index
   * @param length length
   */
  public void characters(char[] c, int i, int length) {
    chars.append(c, i, length);
  }

  /**
   * Start element SAX event
   * 
   * @param uri URI of the element
   * @param localName local name
   * @param qName fully qualified name
   * @param attr attributes
   */
  public void startElement(String uri, String localName, String qName, Attributes attr) {
    chars.setLength(0);
    if (qName.equals(XML_ELEMENT_RESULTS)) {
      results++;
      if (results == 1) {
        return;
      }
    }
    if (results <= 0) {
      return;
    }

    if (qName.equals(XML_ELEMENT_RESULT)) {
      result++;
      if (result == 1) {
        try {
          actObject = resultClass.getConstructor(new Class[0]).newInstance(new Object[0]);
        } catch (Exception e) {
          LOG.error(e.getMessage(), e);
        }
        return;
      }
    }
    actElem = qName;

    for (int i = 0; i < attr.getLength(); i++) {
      if (attr.getQName(i).equalsIgnoreCase(XML_ELEMENT_DATATYPE)) {
        continue;
      }
      try {
        String setterName = "set"
          + Character.toUpperCase(qName.charAt(0))
          + qName.substring(1, qName.length());
        resultClass.getMethod(setterName, new Class[] { String.class}).invoke(
          actObject,
          new Object[] { attr.getValue(i).trim()});
      } catch (Exception e) {
        LOG.error(e.getMessage(), e);
      }
    }
  }

  /**
   * end element SAX event
   * 
   * @param uri URI of the element
   * @param localName local name
   * @param qName fully qualified name
   */
  public void endElement(String uri, String localName, String qName) {
    if (results <= 0) {
      return;
    }
    if (qName.equals(XML_ELEMENT_RESULTS)) {
      results--;
      if (results == 0) {
        return;
      }
    }
    if (qName.equals(XML_ELEMENT_RESULT)) {
      result--;
      if (result == 0) {
        if (actObject != null) {
          resultArray.add(actObject);
          actObject = null;
        }
        return;
      }
    }
    if (actObject != null && qName.equals(actElem) && chars.length() > 0) {
      try {
        String setterName = "set"
          + Character.toUpperCase(actElem.charAt(0))
          + actElem.substring(1, actElem.length());
        resultClass.getMethod(setterName, new Class[] { String.class}).invoke(
          actObject,
          new Object[] { chars.toString()});
      } catch (Exception e) {
        LOG.error(e.getMessage(), e);
      }
    }
    chars.setLength(0);
  }

  /**
   * start document SAX event
   * 
   * @throws org.xml.sax.SAXException SAX exception
   */
  public void startDocument() throws SAXException {
    resultArray.clear();
  }

  /**
   * Returns the result object.
   * 
   * @return result object
   */
  public List<Object> getResult() {
    return (new LinkedList<Object>(resultArray));
  }
}
