package com.qbizm.kramerius.webclient;

import java.io.ByteArrayInputStream;
import java.io.StringWriter;
import java.io.Writer;
import java.net.URLEncoder;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;
import java.util.ResourceBundle;
import java.util.SortedSet;
import java.util.TreeSet;

import javax.el.ValueExpression;
import javax.faces.application.Application;
import javax.faces.application.FacesMessage;
import javax.faces.component.html.HtmlCommandButton;
import javax.faces.component.html.HtmlOutputLink;
import javax.faces.component.html.HtmlOutputText;
import javax.faces.context.FacesContext;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.ActionEvent;
import javax.faces.event.ActionListener;
import javax.servlet.http.HttpServletResponse;
import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.ajax4jsf.component.html.HtmlActionParameter;
import org.apache.axis.utils.ByteArrayOutputStream;
import org.apache.log4j.Logger;
import org.richfaces.component.html.HtmlPanel;

import com.qbizm.kramerius.webclient.repository.RepositoryException;
import com.qbizm.kramerius.webclient.repository.dto.DatastreamDef;
import com.qbizm.kramerius.webclient.repository.dto.MIMETypedStream;
import com.qbizm.kramerius.webclient.repository.dto.ObjectFields;
import com.qbizm.kramerius.webclient.repository.dto.ObjectProfile;
import com.uwyn.jhighlight.renderer.Renderer;
import com.uwyn.jhighlight.renderer.XhtmlRendererFactory;

/**
 * JSF bean for Digital object detail page
 * <p>
 * Copyright (c) 2008 Qbizm technologies, a.s. All rights reserved.
 * <p>
 * This software is the proprietary information of Qbizm technologies, a.s. Use is subject to
 * license terms.
 * <p>
 * Requirements: <br>
 * Keywords: <br>
 * 
 * @author <a href="mailto:pavel.slavicek@qbizm.cz">Pavel Slavicek</a>
 * @version $$ $$
 */
public class DigitalObjectBean implements ActionListener {

  private static final Logger LOG = Logger.getLogger(DigitalObjectBean.class);

  private static final String COMMAND_BUTTON_DOWNLOAD_OCR = "download_ocr";

  private static final String COMMAND_BUTTON_DOWNLOAD_BINARY = "download_bin";

  private static final String PARAMETER_PID = "pid";

  private String objectPid;

  private ObjectFields digitalObject = new ObjectFields();

  private List<DatastreamDef> dataStreamsInfo = null;

  private List<LocationBarItem> bar = null;

  private RepositoryBean repositoryBean;

  private String LOCALISED_MESSAGE = "";

  /**
   * Constructor of the bean
   */
  public DigitalObjectBean() {
    FacesContext context = FacesContext.getCurrentInstance();
    String pid = context.getExternalContext().getRequestParameterMap().get(PARAMETER_PID);
    if (pid != null) {
      this.objectPid = pid;
    }
    pid = context.getExternalContext().getRequestParameterMap().get("objectForm:objectPid");
    if (pid != null && this.objectPid == null) {
      this.objectPid = pid;
    }
    Application application = context.getApplication();
    ValueExpression exp = application.getExpressionFactory().createValueExpression(
      context.getELContext(),
      "#{repositoryBean}",
      RepositoryBean.class);
    this.repositoryBean = (RepositoryBean) exp.getValue(context.getELContext());
  }

  /**
   * Getter for PID
   * 
   * @return
   */
  public String getObjectPid() {
    return objectPid;
  }

  /**
   * Setter for PID
   * 
   * @param pid
   */
  public void setObjectPid(String pid) {
    this.objectPid = pid;
  }

  /**
   * Reads digital object information from Fedora repository
   * 
   * @return
   */
  public ObjectFields getDigitalObject() {
    if (this.digitalObject.getPid() == null && objectPid != null) {
      FacesContext context = FacesContext.getCurrentInstance();
      ResourceBundle bundle = ResourceBundle.getBundle("messages", context.getViewRoot()
        .getLocale());
      try {
        this.LOCALISED_MESSAGE = bundle.getString("error_message_no_digital_object_found");
      } catch (Exception e) {
        this.LOCALISED_MESSAGE = "[error_message_no_digital_object_found]";
      }
      if (objectPid != null) {
        this.objectPid = Utils.removeInfoFedora(getObjectPid());
        try {
          this.digitalObject = this.repositoryBean.getRepository().getObjectFileds(
            "title, pid",
            this.getObjectPid());
          if (this.digitalObject == null) {
            LOG.error("Cannot load digital object definition");
            context.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR,
              LOCALISED_MESSAGE, null));
          }
        } catch (Exception e) {
          LOG.error("Cannot load digital object definition : " + e.getMessage(), e);
          context.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, LOCALISED_MESSAGE,
            null));
        }
      } else {
        context.addMessage(null, new FacesMessage(FacesMessage.SEVERITY_ERROR, LOCALISED_MESSAGE,
          null));
        LOG.error("Page received null pid");
      }
    }
    return digitalObject;
  }

  /**
   * Setter for digital object
   * 
   * @param digitalObject
   */
  public void setDigitalObject(ObjectFields digitalObject) {
    this.digitalObject = digitalObject;
  }

  /**
   * Returns cached digital's datastreams informations
   * 
   * @return
   */
  public List<DatastreamDef> getDataStreamsInfo() {
    if (this.dataStreamsInfo == null && this.repositoryBean != null && this.objectPid != null) {
      try {
        this.dataStreamsInfo = this.repositoryBean.getRepository().getDataStreamsInfo(
          this.objectPid,
          null);
      } catch (Exception e) {
        LOG.error(e.getMessage(), e);
      }
    }
    return dataStreamsInfo;
  }

  /**
   * Setter for datastreams info
   * 
   * @param dataStreamsInfo
   */
  public void setDataStreamsInfo(List<DatastreamDef> dataStreamsInfo) {
    this.dataStreamsInfo = dataStreamsInfo;
  }

  /**
   * Generates JSF panel with datastreams information
   * 
   * @return
   */
  public HtmlPanel getPanel() {
    HtmlPanel panel = new HtmlPanel();
    // Iterates over object's data streams
    List<DatastreamDef> listOfDs = getDataStreamsInfo();
    if (listOfDs!=null) {
      Collections.sort(listOfDs, new Comparator<DatastreamDef>() {

        public int compare(DatastreamDef o1, DatastreamDef o2) {
          if (o1!=null && o2!=null) {
            return o1.getID().compareTo(o2.getID());
          }
          return 0;
        }               
      });    
      
      for (DatastreamDef dsDef : listOfDs) {
        HtmlPanel item = new HtmlPanel();
        panel.getChildren().add(item);
        item.setStyleClass("dataStreamBody");
        
        HtmlOutputText header = new HtmlOutputText();
        item.getChildren().add(header);
        header.setValue("<div class=\"dataStreamHeader\">" + dsDef.getID() + " - " + dsDef.getLabel() + " (" + dsDef.getMIMEType() + ")</div>");
        header.setEscape(false);
        try {
          MIMETypedStream stream = this.repositoryBean.getRepository().getDatastream(this.getObjectPid(), dsDef.getID(), null);
          if ("text/xml".equalsIgnoreCase(dsDef.getMIMEType()) || "application/rdf+xml".equalsIgnoreCase(dsDef.getMIMEType())) {
            HtmlOutputText text = new HtmlOutputText();
            item.getChildren().add(text);
            Renderer renderer = XhtmlRendererFactory.getRenderer(XhtmlRendererFactory.XML);
            ByteArrayOutputStream outStream = new ByteArrayOutputStream();
            ByteArrayInputStream inStream = new ByteArrayInputStream(stream.getStream());
            renderer.highlight(null, inStream, outStream, "utf-8", true);
            text.setValue(new String(outStream.toByteArray()));
            text.setEscape(false);
          } else if ("image/jpeg".equalsIgnoreCase(dsDef.getMIMEType())) {            
            HtmlOutputText text = new HtmlOutputText();
            text.setValue("<img src=\""+this.repositoryBean.getRepositoryUrl() + "/get/" + objectPid +"/" + dsDef.getID() + "\"/>");
            text.setEscape(false);
            item.getChildren().add(text);
          } else {
            HtmlOutputText text = new HtmlOutputText();
            if (stream.getStream()!=null) {
              text.setValue(stream.getStream().length + " bytes");  
            }
            item.getChildren().add(text);
          }
        } catch (Exception e) {
          HtmlOutputText text = new HtmlOutputText();
          text.setValue(e.getMessage()); 
          item.getChildren().add(text);
          LOG.error("Cannot load data stream for object : " + this.getObjectPid() +" , DS_ID:" + dsDef.getID());
        }
        
      }
    }
    return panel;
  }
  
  /**
   * Setter for JSF panel with datastream information
   * @param panel
   */
  public void setPanel(HtmlPanel panel) {
    // Nothing
  }
  
  /**
   * Generates location bar for current digital object
   * @return
   */
  public List<LocationBarItem> getBar() {
    if (this.objectPid!=null) {
      FacesContext context = FacesContext.getCurrentInstance();
      this.bar = new LinkedList<LocationBarItem>();      
      try {        
        ObjectFields objField = this.repositoryBean.getRepository().getObjectFileds("title", Utils.removeInfoFedora(this.objectPid));
        bar.add(0, new LocationBarItem(objField.getTitlesView(), objField.getPid(), getDetailUrl(objField.getPid())));
        objField = getParent(objField.getPid());
        while (objField!=null) {
          String oldPid = objField.getPid();
          bar.add(0, new LocationBarItem(objField.getTitlesView(), objField.getPid(), getDetailUrl(objField.getPid())));
          objField = getParent(objField.getPid());
          if (oldPid!=null && objField!=null && objField.getPid()!=null && oldPid.equals(objField.getPid())) {
            objField = null;
          }
        }
      } catch (Exception e) {
        LOG.error("Cannot build location bar : " + e.getMessage(), e);
      }      
      bar.add(0, new LocationBarItem("Kramerius", null, context.getExternalContext().getRequestContextPath()));
    }        
    return bar;
  }
  
  /**
   * Setter for digital object location bar
   * @param bar
   */
  public void setBar(List<LocationBarItem> bar) {
    this.bar = bar;
  }
  
  /**
   * Method generates URL for location bar item 
   * @param pid
   * @return
   */
  private String getDetailUrl(String pid) {
    FacesContext context = FacesContext.getCurrentInstance();
    DigitalObjectTypeDef def = this.repositoryBean.getDigitalObjectDef(pid);
    return (def==null || !def.isRoot()) ? context.getExternalContext().getRequestContextPath() + "/pages/object.jsf" : 
      context.getExternalContext().getRequestContextPath() + "/pages/objects.jsf";      
  }
  
  /**
   * Method calculates parent for given digital object
   * @param pid
   * @return
   * @throws RepositoryException
   */
  private ObjectFields getParent(String pid) throws RepositoryException {
    ObjectFields parent = null;
    ObjectProfile profile = this.repositoryBean.getRepository().getObjectProfile(pid, null);
    if (profile==null || profile.getObjModels()==null || profile.getObjModels().isEmpty()) {
      return null;
    }
    DigitalObjectTypeDef def = this.repositoryBean.getDigitalObjectDef(pid);    
    if (def!=null && def.isRoot()) {
      return null;
    }
    for (int i = 0; i < profile.getObjModels().size() && def==null; i++) {
      String modelPid = profile.getObjModels().get(i);      
      def = this.repositoryBean.getDigitalObjectDef(modelPid);
    }
    if (def==null) {
      return null;
    }
    if (def!=null && def.getItqlParent()!=null) {
      if (!pid.startsWith("info:fedora/")) {
        pid = "info:fedora/" + pid;
      }
      String itql = def.getItqlParent().replace("[[PID]]", pid);
      List<Object> result = this.repositoryBean.getRepository().riSearch(itql, ObjectFields.class);
      if (result!=null && result.size()>0) {
        int i = 0;
        while (i < result.size() && parent==null) {
          if (!"info:fedora/fedora-system:FedoraObject-3.0".equals(((ObjectFields)result.get(i)).getPid())) {
            parent = (ObjectFields) result.get(i); 
          }
          i++;
        }        
      }
    }
    return parent;
  }
  
  /**
   * Returns basic panel with basic digital's object info
   * @return
   */
  public HtmlPanel getObjectBasicInfo() {
    HtmlPanel panel = new HtmlPanel();    
    if (this.objectPid!=null) {
      try {
        ObjectProfile profile = this.repositoryBean.getRepository().getObjectProfile(this.objectPid, null);
        
        // Renders command link for downloading binary and text content of the page
        if (profile!=null && profile.getObjModels()!=null) {
          if (profile.getObjModels().contains(Utils.MODEL_PAGE)) {
            ResourceBundle messages = ResourceBundle.getBundle("messages");            
            List<DatastreamDef> dataStreams = getDataStreamsInfo();
            if (dataStreams!=null && !dataStreams.isEmpty()) {
              for (DatastreamDef def : dataStreams) {                
                if (Utils.IMG_FULL_DS_ID.equals(def.getID())) {
                  HtmlCommandButton downloadButton = new HtmlCommandButton();
                  panel.getChildren().add(downloadButton);
                  downloadButton.setId(COMMAND_BUTTON_DOWNLOAD_BINARY);
                  downloadButton.addActionListener(this);           
                  downloadButton.setValue(messages.getString("download_content"));
                  downloadButton.setStyleClass("downloadButton");                  
                  HtmlActionParameter param = new HtmlActionParameter();
                  downloadButton.getChildren().add(param);
                  param.setName(PARAMETER_PID);
                  param.setValue(this.getObjectPid());                  
                } else if (Utils.TEXT_OCR_DS_ID.equals(def.getID())) {
                  HtmlCommandButton downloadButtonOcr = new HtmlCommandButton();
                  panel.getChildren().add(downloadButtonOcr);                  
                  downloadButtonOcr.setId(COMMAND_BUTTON_DOWNLOAD_OCR);
                  downloadButtonOcr.addActionListener(this);           
                  downloadButtonOcr.setValue(messages.getString("download_content_ocr_text"));
                  downloadButtonOcr.setStyleClass("downloadButton");
                  HtmlActionParameter param = new HtmlActionParameter();
                  downloadButtonOcr.getChildren().add(param);
                  param.setName(PARAMETER_PID);
                  param.setValue(this.getObjectPid());
                }
              }
            }
          }
          
          // Iterate over all models definitions
          for (String model : profile.getObjModels()) {
            DigitalObjectTypeDef def = this.repositoryBean.getDigitalObjectDef(model);
            if (def!=null && def.getDatastreamsIdsWithStylesheet()!=null) {
              SortedSet<String> defs = new TreeSet<String>();
              defs.addAll(def.getDatastreamsIdsWithStylesheet());
              for (String dsId : defs) {
                
                  HtmlPanel item = new HtmlPanel();
                  panel.getChildren().add(item);
                  item.setStyleClass("dataStreamBody");

                  HtmlOutputText header = new HtmlOutputText();
                  item.getChildren().add(header);
                  header.setValue("<div class=\"dataStreamHeader\">" + dsId + " - " + model + "</div>");
                  header.setEscape(false);
                  
                  String xslt = def.getStylesheet(dsId);
                  MIMETypedStream stream = this.repositoryBean.getRepository().getDatastream(objectPid, dsId, null);
                  if (stream!=null) {
                    String content = null;
                    try {
                      Writer result = new StringWriter();
                      TransformerFactory factory = TransformerFactory.newInstance();
                      Transformer transformer = factory.newTransformer(new StreamSource(
                        this.getClass().getClassLoader().getResourceAsStream(xslt)));
                      transformer.setOutputProperty(OutputKeys.ENCODING, "utf-8");
                      transformer.setOutputProperty(OutputKeys.INDENT, "yes");
                      transformer.setOutputProperty(OutputKeys.OMIT_XML_DECLARATION, "yes"); 
                      transformer.transform(new StreamSource(new ByteArrayInputStream(stream.getStream())), 
                        new StreamResult(result));
                      content = result.toString();
                      
                    } catch (Exception e) {
                      content = e.getMessage();
                    }
                    HtmlOutputText contentText = new HtmlOutputText();
                    item.getChildren().add(contentText);
                    contentText.setValue(content);
                    contentText.setEscape(false);
                  }
              }
            }
          }          
        }        
      } catch (Exception e) {
        LOG.error("Cannot get basic information about digital object :" + e.getMessage(), e);
      }
    }
    // Iterates over object's sub objects
    if (this.objectPid!=null) {
      ObjectProfile profile = null;
      try {
        profile = this.repositoryBean.getRepository().getObjectProfile(this.getObjectPid(), null);
      } catch (RepositoryException e) {
        LOG.error("Cannot load digital object profile: " + e.getMessage(), e);
      }
      if (profile!=null && profile.getObjModels()!=null) {
        for (int i = 0; i < profile.getObjModels().size(); i++) {
          String modelPid = profile.getObjModels().get(i);      
          DigitalObjectTypeDef def = this.repositoryBean.getDigitalObjectDef(modelPid);
          if (def!=null && def.getSubItems()!=null && !def.getSubItems().isEmpty()) {
            HtmlPanel subItemsPanel = new HtmlPanel();
            subItemsPanel.setStyleClass("dataStreamBody");
            panel.getChildren().add(subItemsPanel);
            for (DigitalObjectTypeDef.SubItemDef subItemDef : def.getSubItems()) {
              HtmlPanel subObjPanel = new HtmlPanel();
              subObjPanel.setStyleClass("subObjectPanel");
              boolean childs = addSubObject(subItemDef, subObjPanel);
              if (childs) {
                subItemsPanel.getChildren().add(subObjPanel);
              }
            }
          }          
        }        
      }            
    }    
    return panel;
  }
  public void setObjectBasicInfo(HtmlPanel pane) {
    // Nothing to implement
  }

  /**
   * Reads information for sub digital objects and renders them to the given panel
   * 
   * @param subItemDef
   * @param panel
   */
  private boolean addSubObject(DigitalObjectTypeDef.SubItemDef subItemDef, HtmlPanel panel) {
    boolean resultValue = false;
    panel.setHeader(subItemDef.getTitle());
    String pid = this.objectPid;
    if (!pid.startsWith("info:fedora/")) {
      pid = "info:fedora/" + pid;
    }
    String itql = subItemDef.getItql();
    if (itql != null) {
      itql = itql.replace("[[PID]]", pid);
      try {
        List<Object> result = this.repositoryBean.getRepository()
          .riSearch(itql, ObjectFields.class);
        if (result != null && !result.isEmpty()) {
          resultValue = true;
          boolean isFirst = true;
          for (Object subObj : result) {
            ObjectFields obj = (ObjectFields) subObj;
            if (subItemDef.getDataStreams().isEmpty()) {
              if (!isFirst) {
                HtmlOutputText text = new HtmlOutputText();
                text.setValue(", ");
                panel.getChildren().add(text);
              } else {
                isFirst = false;
              }
              HtmlOutputLink link = new HtmlOutputLink();
              panel.getChildren().add(link);
              link.setTitle(obj.getTitlesView());
              link.setValue("object.jsf?pid="
                + URLEncoder.encode(Utils.removeInfoFedora(obj.getPid()), "UTF-8"));
              HtmlOutputText text = new HtmlOutputText();
              link.getChildren().add(text);
              text.setValue(obj.getTitlesView());
            } else {
              for (String dsIds : subItemDef.getDataStreams()) {
                HtmlOutputText link = new HtmlOutputText();
                panel.getChildren().add(link);
                link.setValue(obj.getTitlesView() + ":" + dsIds);
              }
            }
          }
        }
      } catch (Exception e) {
        LOG.error("Error during loading sub digital objects, itql=" + itql, e);
      }
    }
    return resultValue;
  }

  /**
   * Action listener method implementation
   */
  public void processAction(ActionEvent actionEvent) throws AbortProcessingException {
    FacesContext faces = FacesContext.getCurrentInstance();
    HttpServletResponse response = (HttpServletResponse) faces.getExternalContext().getResponse();
    if (actionEvent.getComponent().getId().equals(COMMAND_BUTTON_DOWNLOAD_OCR)) {
      try {
        MIMETypedStream stream = this.repositoryBean.getRepository().getDatastream(
          this.getObjectPid(),
          Utils.TEXT_OCR_DS_ID,
          null);
        byte[] bytes = {};
        if (stream != null && stream.getStream() != null) {
          bytes = stream.getStream();
        }
        response.setContentType("text/plain");
        response.setContentLength(bytes.length);
        response.setHeader("Content-disposition", "attachment; filename="
          + this.getObjectPid()
          + ".txt");
        response.getOutputStream().write(bytes);
        faces.responseComplete();
      } catch (Exception e) {
        LOG.error("Cannot server datastream data for OCR TEXT", e);
      }
    } else if (actionEvent.getComponent().getId().equals(COMMAND_BUTTON_DOWNLOAD_BINARY)) {
      try {
        MIMETypedStream stream = this.repositoryBean.getRepository().getDatastream(
          this.getObjectPid(),
          Utils.IMG_FULL_DS_ID,
          null);
        byte[] bytes = {};
        if (stream != null && stream.getStream() != null) {
          bytes = stream.getStream();
        }
        String extension = "jpg";
        if (Utils.MIME_TYPES_MAPPING.containsKey(stream.getMIMEType())) {
          extension = Utils.MIME_TYPES_MAPPING.get(stream.getMIMEType());
        }
        response.setContentType(stream.getMIMEType());
        response.setContentLength(bytes.length);
        response.setHeader("Content-disposition", "attachment; filename="
          + this.getObjectPid()
          + "."
          + extension);
        response.getOutputStream().write(bytes);
        faces.responseComplete();
      } catch (Exception e) {
        LOG.error("Cannot server datastream data", e);
      }
    }
  }
}
