package com.qbizm.kramerius.webclient;

import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * Value object for type of digital object definition 
 * <p>
 * Copyright (c) 2008 Qbizm technologies, a.s. All rights reserved.
 * <p>
 * This software is the proprietary information of Qbizm technologies, a.s. Use is subject to
 * license terms.
 * <p>
 * Requirements: <br>
 * Keywords: <br>
 * 
 * @author <a href="mailto:pavel.slavicek@qbizm.cz">Pavel Slavicek</a>
 * @version $$ $$
 */
public class DigitalObjectTypeDef {
  
  private String pid;
  private String title;
  private boolean isRoot;
  private String itqlItems;
  private List<SubItemDef> subItems = new LinkedList<SubItemDef>();
  private String itqlParent;
  private Map<String, String> stylesheets = new HashMap<String, String>();
  
  public DigitalObjectTypeDef(String model, String title, boolean isRoot, String itqlItems,
    List<SubItemDef> subItems, String itqlParent) {
    super();
    this.pid = model;
    this.title = title;
    this.isRoot = isRoot;
    this.itqlItems = itqlItems;
    this.subItems = subItems;
    this.itqlParent = itqlParent;
  }

  public String getPid() {
    return pid;
  }
  
  public void setPid(String model) {
    this.pid = model;
  }
  
  public String getTitle() {
    return title;
  }
  
  public void setTitle(String title) {
    this.title = title;
  }
  
  public boolean isRoot() {
    return isRoot;
  }
  
  public void setRoot(boolean isRoot) {
    this.isRoot = isRoot;
  }
  
  public String getItqlItems() {
    return itqlItems;
  }
  
  public void setSubItems(String itqlItems) {
    this.itqlItems = itqlItems;
  }
  
  public List<SubItemDef> getSubItems() {
    if (this.subItems==null) {
      this.subItems = new LinkedList<SubItemDef>();
    }
    return subItems;
  }
  
  public void setItqlSubItems(List<SubItemDef> itqlSubItems) {
    this.subItems = itqlSubItems;
  }
  
  public String getItqlParent() {
    return itqlParent;
  }
  
  public void setItqlParent(String itqlParent) {
    this.itqlParent = itqlParent;
  }

  
  public Map<String, String> getStylesheets() {
    return stylesheets;
  }

  
  public void setStylesheets(Map<String, String> stylesheets) {
    this.stylesheets = stylesheets;
  }

  public void addStylesheet(String dsId, String source) {
    this.stylesheets.put(dsId, source);
  }
  
  public String getStylesheet(String dsId) {
    return this.stylesheets.containsKey(dsId) ? this.stylesheets.get(dsId) : null;
  }
  
  public Set<String> getDatastreamsIdsWithStylesheet() {
    Set<String> keys = this.stylesheets.keySet();
    return keys;
  }

  @Override
  public String toString() {
    StringBuffer sb = new StringBuffer();
    sb.append(this.getClass().getName());
    sb.append("[");
    sb.append("PID=\"" + this.pid + "\"");
    sb.append(", TITLE=\"" + this.title + "\"");
    sb.append(", ISROOT=\"" + this.isRoot + "\"");
    sb.append(", ITQLITEMS=\"" + this.itqlItems + "\"");
    sb.append(", SUBOBJECTS=\"" + this.subItems + "\"");
    sb.append(", ITQLPARENT=\"" + this.itqlParent + "\"");
    sb.append(", STYLESHEETS=\"" + this.stylesheets + "\"");
    sb.append("]");
    return sb.toString();
  }
  
  /***
   * SubItem definition
   */
  static class SubItemDef {
    private String title;
    private String itql;
    private Set<String> dataStreams = new HashSet<String>();
    
    public String getTitle() {
      return title;
    }
    
    public void setTitle(String title) {
      this.title = title;
    }
    
    public String getItql() {
      return itql;
    }
    
    public void setItql(String itql) {
      this.itql = itql;
    }
    
    public Set<String> getDataStreams() {
      return dataStreams;
    }
    
    public void setDataStreams(Set<String> dataStreams) {
      this.dataStreams = dataStreams;
    }
    
    @Override
    public String toString() {
      StringBuffer sb = new StringBuffer();
      sb.append(this.getClass());
      sb.append("[");
      sb.append("title=\"" + title + "\"");
      sb.append(", itql=\"" + itql + "\"");
      sb.append(", dataStreams=\"" + dataStreams + "\"");
      sb.append("]");
      return sb.toString();
    }

    public void addDataStreams(String value) {
      if (value!=null) {
        if (value.indexOf(",")<0) {
          this.dataStreams.add(value);
        } else {
          String ds[] = value.split(",");
          if (ds!=null) {            
            this.dataStreams.addAll(Arrays.asList(ds));
          }
        }
      }
    }
  }
}