package com.qbizm.kramerius.webclient;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.ResourceBundle;

import javax.el.ValueExpression;
import javax.faces.application.Application;
import javax.faces.application.FacesMessage;
import javax.faces.context.FacesContext;

import org.apache.log4j.Logger;

import com.qbizm.kramerius.webclient.repository.RepositoryException;
import com.qbizm.kramerius.webclient.repository.dto.ObjectFields;

/**
 * JSF bean for list of Digital objects page 
 * <p>
 * Copyright (c) 2008 Qbizm technologies, a.s. All rights reserved.
 * <p>
 * This software is the proprietary information of Qbizm technologies, a.s. Use is subject to
 * license terms.
 * <p>
 * Requirements: <br>
 * Keywords: <br>
 * 
 * @author <a href="mailto:pavel.slavicek@qbizm.cz">Pavel Slavicek</a>
 * @version $$ $$
 */
public class DigitalObjectsBean {
  
  private static final Logger LOG = Logger.getLogger(DigitalObjectsBean.class);
  
  private String modelPid;
  
  private List<ObjectFields> objects;
  
  private List<LocationBarItem> bar;
  
  private String LOCALISED_MESSAGE = "";
 
  private RepositoryBean repositoryBean;
  
  public DigitalObjectsBean() {
    FacesContext context = FacesContext.getCurrentInstance();
    Application application = context.getApplication();

    if (context.getExternalContext().getRequestParameterMap().get("pid")!=null) {
      this.modelPid = Utils.removeInfoFedora(context.getExternalContext().getRequestParameterMap().get("pid"));
    }      
    ValueExpression exp = application.getExpressionFactory().createValueExpression(context.getELContext(), "#{repositoryBean}" , RepositoryBean.class);
    this.repositoryBean = (RepositoryBean) exp.getValue(context.getELContext());    
    ResourceBundle bundle = ResourceBundle.getBundle("messages", context.getViewRoot().getLocale());
    try {
      this.LOCALISED_MESSAGE = bundle.getString("error_message_no_digital_objects_found");
    } catch (Exception e) {
      this.LOCALISED_MESSAGE = "[error_message_no_digital_objects_found]";
    }    
    this.objects = getListOfDigitalObjects();
  }
    
  private List<ObjectFields> getListOfDigitalObjects() {
    FacesContext context = FacesContext.getCurrentInstance();
    DigitalObjectTypeDef digiDef = repositoryBean.getDigitalObjectDef(getModelPid());
    List<ObjectFields> digiObjects = new ArrayList<ObjectFields>();
    if (digiDef!=null) {
      try {
        List<Object> objs = repositoryBean.getRepository().riSearch(digiDef.getItqlItems(), ObjectFields.class);
        if (objs!=null && !objs.isEmpty()) {
          for (Object obj : objs) {
            ObjectFields objFld = (ObjectFields) obj;
            objFld.setPid(Utils.removeInfoFedora(objFld.getPid()));
            digiObjects.add(objFld);
          }
        } else {
          context.addMessage("objects", new FacesMessage(FacesMessage.SEVERITY_WARN, LOCALISED_MESSAGE, null));
          LOG.warn("Fedora repository returned empty list of digital objects : ");
          LOG.warn("Model PID : " + getModelPid());
          LOG.warn("Model PID : " + digiDef.getItqlItems());
        }
      } catch (RepositoryException e) {
        LOG.error("Cannot get list of digital objects for model pid " + e.getMessage(), e);
        LOG.error("Model PID : " + getModelPid());
        LOG.error("Model PID : " + digiDef.getItqlItems());                
        context.addMessage("objects", new FacesMessage(FacesMessage.SEVERITY_ERROR, LOCALISED_MESSAGE, null));
      }
    }
    return digiObjects;
  }

  public String getModelPid() {
    return modelPid;
  }
  
  public void setModelPid(String modelPid) {
    this.modelPid = modelPid;
  }
  
  public List<ObjectFields> getObjects() {
    return objects;
  }
  
  public void setObjects(List<ObjectFields> objects) {
    this.objects = objects;
  }

  public List<LocationBarItem> getBar() {    
    if (this.modelPid!=null) {
      FacesContext context = FacesContext.getCurrentInstance();
      this.bar = new LinkedList<LocationBarItem>();      
      try {        
        ObjectFields objField = this.repositoryBean.getRepository().getObjectFileds("title", this.modelPid);
        if (objField!=null) {
          bar.add(0, new LocationBarItem(objField.getTitlesView(), objField.getPid(), context.getExternalContext().getRequestContextPath() + "/pages/objects.jsf"));  
        }
      } catch (Exception e) {
        LOG.error("Cannot build location bar : " + e.getMessage(), e);
      }      
      bar.add(0, new LocationBarItem("Kramerius", null, context.getExternalContext().getRequestContextPath()));
    }        
    return bar;
  }
  
  public void setBar(List<LocationBarItem> bar) {
    this.bar = bar;
  }
}
